@@ -78,9 +78,9 @@ def _galerkin(integrands, domainSpace=None, rangeSpace=None,
             except AttributeError:
                 raise ValueError("no domain space provided and could not deduce from form provided")
         if modelParam:
-            integrands = makeIntegrands(domainSpace.grid,integrands,*modelParam)
+            integrands = makeIntegrands(domainSpace.gridView,integrands,*modelParam)
         else:
-            integrands = makeIntegrands(domainSpace.grid,integrands)
+            integrands = makeIntegrands(domainSpace.gridView,integrands)
 
     if virtualize is None:
         virtualize = integrands.virtualized
@@ -128,7 +128,8 @@ def _galerkin(integrands, domainSpace=None, rangeSpace=None,
         typeName = 'DirichletWrapperOperator< ' + typeName + ' >'
 
     setCommunicate = Method('setCommunicate', '''[]( DuneType &self, const bool communicate ) { self.setCommunicate( communicate ); }''' )
-    op = load(includes, typeName, setCommunicate, constructor).Operator(domainSpace,rangeSpace,integrands)
+    gridSizeInterior = Method('gridSizeInterior', '''[]( DuneType &self ) { return self.gridSizeInterior(); }''' )
+    op = load(includes, typeName, setCommunicate, gridSizeInterior, constructor).Operator(domainSpace,rangeSpace,integrands)
     op.model = integrands
     # apply communicate flag
     op.setCommunicate( communicate )
@@ -170,9 +171,9 @@ def h1(model, domainSpace=None, rangeSpace=None):
             except AttributeError:
                 raise ValueError("no domain space provided and could not deduce from form provided")
         if modelParam:
-            model = makeElliptic(domainSpace.grid,model,*modelParam)
+            model = makeElliptic(domainSpace.gridView,model,*modelParam)
         else:
-            model = makeElliptic(domainSpace.grid,model)
+            model = makeElliptic(domainSpace.gridView,model)
 
     if not hasattr(rangeSpace,"interpolate"):
         raise ValueError("wrong range space")
